clc
clear all
close all
%% Importing data from Excel

%Brysymfonien 30 meters between box-girders, without guide vanes
BS30=xlsread('ADbruSymf.xlsx','A24:W31');
BS30parameters=xlsread('ADbruSymf.xlsx','I33:W35');
B30=BS30parameters;
BS30par=[0 0 0;0 0 0;0 0 0;0 0 0;0 0 0;0 0 0;...
    B30(:,1)';B30(:,3)';B30(:,5)';B30(:,7)';0 0 0;0 0 0;...
    B30(:,9)';B30(:,11)';B30(:,13)';B30(:,15)';0 0 0;0 0 0];


%Brysymfonien 30 meters between box-girders, with guide vanes
BS30GV=xlsread('ADbruSymf.xlsx','A5:W13');
BS30GVparameters=xlsread('ADbruSymf.xlsx','I15:W17');
B30GV=BS30GVparameters;
BS30GVpar=[0 0 0;0 0 0;0 0 0;0 0 0;0 0 0;0 0 0;...
    B30GV(:,1)';B30GV(:,3)';B30GV(:,5)';B30GV(:,7)';0 0 0;0 0 0;...
    B30GV(:,9)';B30GV(:,11)';B30GV(:,13)';B30GV(:,15)';0 0 0;0 0 0];


%Brysymfonien 20 meters between box-girders, with guide vanes
BS20GV=xlsread('ADbruSymf.xlsx','A42:W50');
BS20GVparameters=xlsread('ADbruSymf.xlsx','I52:W54');
B20GV=BS20GVparameters;
BS20GVpar=[0 0 0;0 0 0;0 0 0;0 0 0;0 0 0;0 0 0;...
    B20GV(:,1)';B20GV(:,3)';B20GV(:,5)';B20GV(:,7)';0 0 0;0 0 0;...
    B20GV(:,9)';B20GV(:,11)';B20GV(:,13)';B20GV(:,15)';0 0 0;0 0 0];


%Brysymfonien 20 meters between box-girders, with guide vanes
BS15GV=xlsread('ADbruSymf.xlsx','A61:W65');
BS15GVparameters=xlsread('ADbruSymf.xlsx','I67:W69');
B15GV=BS15GVparameters;
BS15GVpar=[0 0 0;0 0 0;0 0 0;0 0 0;0 0 0;0 0 0;...
    B15GV(:,1)';B15GV(:,3)';B15GV(:,5)';B15GV(:,7)';0 0 0;0 0 0;...
    B15GV(:,9)';B15GV(:,11)';B15GV(:,13)';B15GV(:,15)';0 0 0;0 0 0];


save('BS30par','BS30par')
save('BS30GVpar','BS30GVpar')
save('BS20GVpar','BS20GVpar')
save('BS15GVpar','BS15GVpar')
%% Defining the polynomial curves
% Reduced velocity vector (V_red=V/(omega*B^*))
Vred=0:0.001:20;

% AD=[P1* P2* P3* P4* P5* P6* H1* H2* H3* H4* H5* H6* A1* A2* A3* A4* A5* A6*]
for i = 1:18
    for n=1:length(Vred)
        ADBS30(i,n)=BS30par(i,1)*(Vred(n)*2*pi)^2+BS30par(i,2)*(Vred(n)*2*pi)+...
            BS30par(i,3);  
        
        ADBS30GV(i,n)=BS30GVpar(i,1)*(Vred(n)*2*pi)^2+BS30GVpar(i,2)*(Vred(n)*2*pi)+...
            BS30GVpar(i,3);
        
        ADBS20GV(i,n)=BS20GVpar(i,1)*(Vred(n)*2*pi)^2+BS20GVpar(i,2)*(Vred(n)*2*pi)+...
            BS20GVpar(i,3);
        
        ADBS15GV(i,n)=BS15GVpar(i,1)*(Vred(n)*2*pi)^2+BS15GVpar(i,2)*(Vred(n)*2*pi)+...
            BS15GVpar(i,3);
    end
end




%% Plotting the experimental results and polynomials fitted to data
% Section BS30
figure(1)
set(gcf,'Name','Aerodynamic derivatives Section BS30','Numbertitle','off')
plot(subplot(4,2,1),BS30(:,3),BS30(:,9),'o',Vred,ADBS30(7,:)),xlim([0 11])
ylabel('$H^*_1$','interpreter','latex')

plot(subplot(4,2,2),BS30(:,7),BS30(:,11),'o',Vred,ADBS30(8,:)),xlim([0 8])
ylabel('$H^*_2$','interpreter','latex')

plot(subplot(4,2,3),BS30(:,3),BS30(:,17),'o',Vred,ADBS30(13,:)),xlim([0 11])
ylabel('$A^*_1$','interpreter','latex')

plot(subplot(4,2,4),BS30(:,7),BS30(:,19),'o',Vred,ADBS30(14,:)),xlim([0 8])
ylabel('$A^*_2$','interpreter','latex')

plot(subplot(4,2,5),BS30(:,3),BS30(:,15),'o',Vred,ADBS30(10,:)),xlim([0 11])
ylabel('$H^*_4$','interpreter','latex')

plot(subplot(4,2,6),BS30(:,7),BS30(:,13),'o',Vred,ADBS30(9,:)),xlim([0 8])
ylabel('$H^*_3$','interpreter','latex')

plot(subplot(4,2,7),BS30(:,3),BS30(:,23),'o',Vred,ADBS30(16,:)),xlim([0 11])
ylabel('$A^*_4$','interpreter','latex')
xlabel('Reduced velocity V/($\omega_z *B^*$)','interpreter','latex')

plot(subplot(4,2,8),BS30(:,7),BS30(:,21),'o',Vred,ADBS30(15,:)),xlim([0 8])
ylabel('$A^*_3$','interpreter','latex')
xlabel('Reduced velocity V/($\omega_\theta *B^*$)','interpreter','latex')

h=get(gcf,'Children');  
for i=1:size(h,1)
    k=get(h(i,1),'Children');
    for j=1:size(k,1)
        if j==1
            set(k(j,1),'color','r','LineStyle','-.')
        end
    end
end

%% Section BS30GV
figure(2)
set(gcf,'Name','Aerodynamic derivatives Section BS30GV','Numbertitle','off')
plot(subplot(4,2,1),BS30GV(:,3),BS30GV(:,9),'o',Vred,ADBS30GV(7,:)),xlim([0 18])
ylabel('$H^*_1$','interpreter','latex')

plot(subplot(4,2,2),BS30GV(:,7),BS30GV(:,11),'o',Vred,ADBS30GV(8,:)),xlim([0 14])
ylabel('$H^*_2$','interpreter','latex')

plot(subplot(4,2,3),BS30GV(:,3),BS30GV(:,17),'o',Vred,ADBS30GV(13,:)),xlim([0 18])
ylabel('$A^*_1$','interpreter','latex')

plot(subplot(4,2,4),BS30GV(:,7),BS30GV(:,19),'o',Vred,ADBS30GV(14,:)),xlim([0 14])
ylabel('$A^*_2$','interpreter','latex')

plot(subplot(4,2,5),BS30GV(:,3),BS30GV(:,15),'o',Vred,ADBS30GV(10,:)),xlim([0 18])
ylabel('$H^*_4$','interpreter','latex')

plot(subplot(4,2,6),BS30GV(:,7),BS30GV(:,13),'o',Vred,ADBS30GV(9,:)),xlim([0 14])
ylabel('$H^*_3$','interpreter','latex')

plot(subplot(4,2,7),BS30GV(:,3),BS30GV(:,23),'o',Vred,ADBS30GV(16,:)),xlim([0 18])
ylabel('$A^*_4$','interpreter','latex')
xlabel('Reduced velocity V/($\omega_z *B^*$)','interpreter','latex')

plot(subplot(4,2,8),BS30GV(:,7),BS30GV(:,21),'o',Vred,ADBS30GV(15,:)),xlim([0 14])
ylabel('$A^*_3$','interpreter','latex')
xlabel('Reduced velocity V/($\omega_\theta *B^*$)','interpreter','latex')

h=get(gcf,'Children');  
for i=1:size(h,1)
    k=get(h(i,1),'Children');
    for j=1:size(k,1)
        if j==1
            set(k(j,1),'color','r','LineStyle','-.')
        end
    end
end

%% Section BS20GV
figure(3)
set(gcf,'Name','Aerodynamic derivatives Section BS20GV','Numbertitle','off')
plot(subplot(4,2,1),BS20GV(:,3),BS20GV(:,9),'o',Vred,ADBS20GV(7,:)),xlim([0 18])
ylabel('$H^*_1$','interpreter','latex')

plot(subplot(4,2,2),BS20GV(:,7),BS20GV(:,11),'o',Vred,ADBS20GV(8,:)),xlim([0 15])
ylabel('$H^*_2$','interpreter','latex')

plot(subplot(4,2,3),BS20GV(:,3),BS20GV(:,17),'o',Vred,ADBS20GV(13,:)),xlim([0 18])
ylabel('$A^*_1$','interpreter','latex')

plot(subplot(4,2,4),BS20GV(:,7),BS20GV(:,19),'o',Vred,ADBS20GV(14,:)),xlim([0 15])
ylabel('$A^*_2$','interpreter','latex')

plot(subplot(4,2,5),BS20GV(:,3),BS20GV(:,15),'o',Vred,ADBS20GV(10,:)),xlim([0 18])
ylabel('$H^*_4$','interpreter','latex')

plot(subplot(4,2,6),BS20GV(:,7),BS20GV(:,13),'o',Vred,ADBS20GV(9,:)),xlim([0 15])
ylabel('$H^*_3$','interpreter','latex')

plot(subplot(4,2,7),BS20GV(:,3),BS20GV(:,23),'o',Vred,ADBS20GV(16,:)),xlim([0 18])
ylabel('$A^*_4$','interpreter','latex')
xlabel('Reduced velocity V/($\omega_z *B^*$)','interpreter','latex')

plot(subplot(4,2,8),BS20GV(:,7),BS20GV(:,21),'o',Vred,ADBS20GV(15,:)),xlim([0 15])
ylabel('$A^*_3$','interpreter','latex')
xlabel('Reduced velocity V/($\omega_\theta *B^*$)','interpreter','latex')


h=get(gcf,'Children');  
for i=1:size(h,1)
    k=get(h(i,1),'Children');
    for j=1:size(k,1)
        if j==1
            set(k(j,1),'color','r','LineStyle','-.')
        end
    end
end



%% Section BS15GV
figure(3)
set(gcf,'Name','Aerodynamic derivatives Section BS15GV','Numbertitle','off')
plot(subplot(4,2,1),BS15GV(:,3),BS15GV(:,9),'o',Vred,ADBS15GV(7,:)),xlim([0 12])
ylabel('$H^*_1$','interpreter','latex')

plot(subplot(4,2,2),BS15GV(:,7),BS15GV(:,11),'o',Vred,ADBS15GV(8,:)),xlim([0 8])
ylabel('$H^*_2$','interpreter','latex')

plot(subplot(4,2,3),BS15GV(:,3),BS15GV(:,17),'o',Vred,ADBS15GV(13,:)),xlim([0 12])
ylabel('$A^*_1$','interpreter','latex')

plot(subplot(4,2,4),BS15GV(:,7),BS15GV(:,19),'o',Vred,ADBS15GV(14,:)),xlim([0 8])
ylabel('$A^*_2$','interpreter','latex')

plot(subplot(4,2,5),BS15GV(:,3),BS15GV(:,15),'o',Vred,ADBS15GV(10,:)),xlim([0 12])
ylabel('$H^*_4$','interpreter','latex')

plot(subplot(4,2,6),BS15GV(:,7),BS15GV(:,13),'o',Vred,ADBS15GV(9,:)),xlim([0 8])
ylabel('$H^*_3$','interpreter','latex')

plot(subplot(4,2,7),BS15GV(:,3),BS15GV(:,23),'o',Vred,ADBS15GV(16,:)),xlim([0 12])
ylabel('$A^*_4$','interpreter','latex')
xlabel('Reduced velocity V/($\omega_z *B^*$)','interpreter','latex')

plot(subplot(4,2,8),BS15GV(:,7),BS15GV(:,21),'o',Vred,ADBS15GV(15,:)),xlim([0 8])
ylabel('$A^*_3$','interpreter','latex')
xlabel('Reduced velocity V/($\omega_\theta *B^*$)','interpreter','latex')


h=get(gcf,'Children');  
for i=1:size(h,1)
    k=get(h(i,1),'Children');
    for j=1:size(k,1)
        if j==1
            set(k(j,1),'color','r','LineStyle','-.')
        end
    end
end




%% Comparing BS30/BS30GV

figure(1)
set(gcf,'Name','Aerodynamic derivatives Section BS30','Numbertitle','off')
plot(subplot(4,2,1),BS30(:,3),BS30(:,9),'o',Vred,ADBS30(7,:),BS30GV(:,3),...
    BS30GV(:,9),'o',Vred,ADBS30GV(7,:)),xlim([0 18])
ylabel('$H^*_1$','interpreter','latex')

plot(subplot(4,2,2),BS30(:,7),BS30(:,11),'o',Vred,ADBS30(8,:),...
    BS30GV(:,7),BS30GV(:,11),'o',Vred,ADBS30GV(8,:)),xlim([0 18])
ylabel('$H^*_2$','interpreter','latex')

plot(subplot(4,2,3),BS30(:,3),BS30(:,17),'o',Vred,ADBS30(13,:),...
    BS30GV(:,3),BS30GV(:,17),'o',Vred,ADBS30GV(13,:)),xlim([0 18])
ylabel('$A^*_1$','interpreter','latex')

plot(subplot(4,2,4),BS30(:,7),BS30(:,19),'o',Vred,ADBS30(14,:),...
    BS30GV(:,7),BS30GV(:,19),'o',Vred,ADBS30GV(14,:)),xlim([0 18])
ylabel('$A^*_2$','interpreter','latex')

plot(subplot(4,2,5),BS30(:,3),BS30(:,15),'o',Vred,ADBS30(10,:),...
    BS30GV(:,3),BS30GV(:,15),'o',Vred,ADBS30GV(10,:)),xlim([0 18])
ylabel('$H^*_4$','interpreter','latex')

plot(subplot(4,2,6),BS30(:,7),BS30(:,13),'o',Vred,ADBS30(9,:),...
    BS30GV(:,7),BS30GV(:,13),'o',Vred,ADBS30GV(9,:)),xlim([0 18])
ylabel('$H^*_3$','interpreter','latex')

plot(subplot(4,2,7),BS30(:,3),BS30(:,23),'o',Vred,ADBS30(16,:),...
    BS30GV(:,3),BS30GV(:,23),'o',Vred,ADBS30GV(16,:)),xlim([0 18])
ylabel('$A^*_4$','interpreter','latex')
xlabel('Reduced velocity V/($\omega_z *B^*$)','interpreter','latex')

plot(subplot(4,2,8),BS30(:,7),BS30(:,21),'o',Vred,ADBS30(15,:),...
    BS30GV(:,7),BS30GV(:,21),'o',Vred,ADBS30GV(15,:)),xlim([0 18])
ylabel('$A^*_3$','interpreter','latex')
xlabel('Reduced velocity V/($\omega_\theta *B^*$)','interpreter','latex')

% h=get(gcf,'Children');  
% for i=1:size(h,1)
%     k=get(h(i,1),'Children');
%     for j=1:size(k,1)
%         if j==1
%             set(k(j,1),'color','r','LineStyle','-.')
%         end
%     end
% end



