clc
clear all
close all
%% 
VALGT=[1:35];                           % Number of modes to be plotted
Nodes=185;
N_CableNodes=185;
%% Importing the data from ABAQUS
[Eigenvectors,Eigenvalues,EffMassVec,TotEffMassVec]...
    =read_ABAQUS_dat2('filename.dat',Nodes);
omegaomega=(Eigenvalues(VALGT,3));
modalmass=Eigenvalues(VALGT,5);

%% Plotting the effective mass for each node

% Defining the total effectiv mass matrix
TotEffMassVec=[3.73218E+06 9.13276E+07 9.19266E+07 1.48813E+12 4.12136E+14 4.12959E+14];

ModeNR=Eigenvalues(min(VALGT):max(VALGT),1);

% Modal Contribution - X translation
EffXTrans=EffMassVec(:,2)/TotEffMassVec(1,1)*100;
XTrans=EffXTrans(min(VALGT):max(VALGT));
% Modal Contribution - Y translation
EffYTrans=EffMassVec(:,3)/TotEffMassVec(1,2)*100;
YTrans=EffYTrans(min(VALGT):max(VALGT));
% Modal Contribution - Y translation
EffZTrans=EffMassVec(:,4)/TotEffMassVec(1,3)*100;
ZTrans=EffZTrans(min(VALGT):max(VALGT));

% Modal Contribution - X rotation
EffXRot=EffMassVec(:,5)/TotEffMassVec(1,4)*100;
XRot=EffXRot(min(VALGT):max(VALGT));
% Modal Contribution - Y rotation
EffYRot=EffMassVec(:,6)/TotEffMassVec(1,5)*100;
YRot=EffYRot(min(VALGT):max(VALGT));
% Modal Contribution - Z rotation
EffZRot=EffMassVec(:,7)/TotEffMassVec(1,6)*100;
ZRot=EffZRot(min(VALGT):max(VALGT));

TransVec=[XTrans YTrans ZTrans];
RotVec=[XRot YRot ZRot];

n = length(XTrans);
%% X - Translation
figure(1)
k = 128;                                    % Number of colors in color table
colormap(summer(k));                        % Expand the previous colormap
h1=bar(ModeNR,XTrans,'stacked');
xlabel('Mode number','interpreter','latex')
ylabel('Percentage Contribution','interpreter','latex'),xlim([0 38])
title('Modal Contribution - X Translation','interpreter','latex')
shading interp                              % Needed to graduate colors
ch=get(h1,'Children');
fvd = get(ch,'Faces');
fvcd = get(ch,'FaceVertexCData');
[zs, izs] = sortrows(TransVec(:,1));

for j = 1:n
    color = floor(k*TransVec(izs(j),1)/100)+1; % Interpolate a color index
    row = izs(j);                           % Look up actual row # in data
    fvcd(fvd(row,1)) = 1;                   % Color base vertices 1st index
    fvcd(fvd(row,4)) = 1;    
    fvcd(fvd(row,2)) = color;               % Assign top vertices color
    fvcd(fvd(row,3)) = color;
end
set(ch,'FaceVertexCData', fvcd);            % Apply the vertex coloring
set(ch,'EdgeColor','k')                     % Give bars black borders
%% Y - Translation
figure(2)
k = 128;
colormap(summer(k));
h2=bar(ModeNR,YTrans,'stacked');
xlabel('Mode number','interpreter','latex')
ylabel('Percentage Contribution','interpreter','latex'),xlim([0 38])
title('Modal Contribution - Y Translation','interpreter','latex')
shading interp                      
ch=get(h2,'Children');
fvd = get(ch,'Faces');
fvcd = get(ch,'FaceVertexCData');
[zs, izs] = sortrows(TransVec(:,2));

for j = 1:n
    color = floor(k*TransVec(izs(j),2)/100)+1;     
    row = izs(j);               
    fvcd(fvd(row,1)) = 1;       
    fvcd(fvd(row,4)) = 1;    
    fvcd(fvd(row,2)) = color;   
    fvcd(fvd(row,3)) = color;
end
set(ch,'FaceVertexCData', fvcd);  
set(ch,'EdgeColor','k')           
%% Z - Translation
figure(3)
k = 128;
colormap(summer(k));
h3=bar(ModeNR,ZTrans,'stacked');
xlabel('Mode number','interpreter','latex')
ylabel('Percentage Contribution','interpreter','latex'),xlim([0 38])
title('Modal Contribution - Z Translation','interpreter','latex')
shading interp                      
ch=get(h3,'Children');
fvd = get(ch,'Faces');
fvcd = get(ch,'FaceVertexCData');
[zs, izs] = sortrows(TransVec(:,3));

for j = 1:n
    color = floor(k*TransVec(izs(j),3)/100)+1;       
    row = izs(j);               
    fvcd(fvd(row,1)) = 1;       
    fvcd(fvd(row,4)) = 1;    
    fvcd(fvd(row,2)) = color;   
    fvcd(fvd(row,3)) = color;
end
set(ch,'FaceVertexCData', fvcd);  
set(ch,'EdgeColor','k')           

%% X - Rotation
figure(4)
k = 128;
colormap(summer(k));
h4=bar(ModeNR,XRot,'stacked');
xlabel('Mode number','interpreter','latex')
ylabel('Percentage Contribution','interpreter','latex'),xlim([0 38])
title('Modal Contribution - X Rotation','interpreter','latex')
shading interp                      
ch=get(h4,'Children');
fvd = get(ch,'Faces');
fvcd = get(ch,'FaceVertexCData');
[zs, izs] = sortrows(RotVec(:,1));

for j = 1:n
    color = floor(k*RotVec(izs(j),1)/100)+1;   
    row = izs(j);               
    fvcd(fvd(row,1)) = 1;       
    fvcd(fvd(row,4)) = 1;    
    fvcd(fvd(row,2)) = color;   
    fvcd(fvd(row,3)) = color;
end
set(ch,'FaceVertexCData', fvcd);  
set(ch,'EdgeColor','k')        

%% Y - Rotation
figure(5)
k = 128;
colormap(summer(k));
h5=bar(ModeNR,YRot,'stacked');
xlabel('Mode number','interpreter','latex')
ylabel('Percentage Contribution','interpreter','latex'),xlim([0 38])
title('Modal Contribution - Y Rotation','interpreter','latex')
shading interp                      
ch=get(h5,'Children');
fvd = get(ch,'Faces');
fvcd = get(ch,'FaceVertexCData');
[zs, izs] = sortrows(RotVec(:,2));

for j = 1:n
    color = floor(k*RotVec(izs(j),2)/100)+1;      
    row = izs(j);               
    fvcd(fvd(row,1)) = 1;       
    fvcd(fvd(row,4)) = 1;    
    fvcd(fvd(row,2)) = color;   
    fvcd(fvd(row,3)) = color;
end
set(ch,'FaceVertexCData', fvcd);  
set(ch,'EdgeColor','k') 

%% Z - Rotation
figure(6)
k = 128;
colormap(summer(k));
h6=bar(ModeNR,ZRot,'stacked');
xlabel('Mode number','interpreter','latex')
ylabel('Percentage Contribution','interpreter','latex'),xlim([0 38])
title('Modal Contribution - Z Rotation','interpreter','latex')
shading interp                      
ch=get(h6,'Children');
fvd = get(ch,'Faces');
fvcd = get(ch,'FaceVertexCData');
[zs, izs] = sortrows(RotVec(:,3));

for j = 1:n
    color = floor(k*RotVec(izs(j),3)/100)+1;   
    row = izs(j);               
    fvcd(fvd(row,1)) = 1;       
    fvcd(fvd(row,4)) = 1;    
    fvcd(fvd(row,2)) = color;   
    fvcd(fvd(row,3)) = color;
end
set(ch,'FaceVertexCData', fvcd);  
set(ch,'EdgeColor','k')        





















