%% Description
% This script import the *.dat result file from ABAQUS and uses the
% function read_ABAQUS_dat to extract the eigenvalues and eigenvectors for 
% the chosen number of modes
clc
clear all
close all
%% 
VALGT=[1:35];       % Number of modes to be plotted
Nodes=185;          % Number of nodes along the girder where displacements 
                    % are extracted
CNodes=187;         % Nodes along the cable for extracting displacements
                    
%% Importing the data from ABAQUS
[Eigenvectors,Eigenvalues,CableEigenvec]...
    =read_ABAQUS_dat('Analysis1.dat',Nodes,CNodes);
omegaomega=(Eigenvalues(VALGT,3));
%% Defining the modes and sort the table by the x-coordinate (along bridge)
Coordinates=Eigenvectors(:,2:4);
[~, b]=sort(Coordinates(:,1));
Coordinates=Coordinates(b,:)/max(Coordinates(:,1));
Coor=Coordinates(:,1);
xmin=min(Coor(:,1));
xmax=max(Coor(:,1));

phiphi=zeros(3,size(Eigenvectors,1),length(VALGT));
B=25;



%% Plotting modes as Symmetric or Asymmetric
% Each plot containing the tree first symmetric or asymmetric modes of 
% horizontal, vertical or torsional displacements

% Identifying wich mode that are hor., vert. or torsional

% Description of modes

%HSn    n-th Horizontal Symmetric mode
%HAn    n-th Horizontal Asymmetric mode

%VSn    n-th Vertical Symmetric mode
%VAn    n-th Vertical Asymmetric mode

%TSn    n-th Torsional Symmetric mode
%TAn    n-th Torsional Aymmetric mode

teller=min(VALGT);
for n=1:length(omegaomega)
    phiphi(2,:,teller)=Eigenvectors(b,6,n+min(VALGT)-1)';
    phiphi(1,:,teller)=Eigenvectors(b,7,n+min(VALGT)-1)';
    phiphi(3,:,teller)=Eigenvectors(b,8,n+min(VALGT)-1)';
    Skalering=max([phiphi(1,:,teller) phiphi(2,:,teller) B/2*phiphi(3,:,teller) ]);
    teller=teller+1;
end

HS1=1;          VS1=5;          TS1=11;
HS2=4;          VS2=9;          TS2=14;
HS3=11;         VS3=15;         TS3=31;
HA1=2;          VA1=3;          TA1=16;
HA2=6;          VA2=12;         TA2=26;
HA3=17;         VA3=18;         TA3=33;

%% Horizontal Symmetric modes
figure
subplot(3,1,1),plot(Coor,phiphi(1,:,HS1),Coor,phiphi(2,:,HS1),Coor,B/2*phiphi(3,:,HS1))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['1st HS'],'interpreter','latex')
    grid on
subplot(3,1,2), plot(Coor,phiphi(1,:,HS2),Coor,phiphi(2,:,HS2),Coor,B/2*phiphi(3,:,HS2))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['2nd HS'],'interpreter','latex')
    grid on
subplot(3,1,3), plot(Coor,phiphi(1,:,HS3),Coor,phiphi(2,:,HS3),Coor,B/2*phiphi(3,:,HS3))
   leg=legend('H','V','T');
   set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
   xlim([xmin xmax]),ylim([-1 1]),title(['3rd HS'],'interpreter','latex')
   grid on,xlabel('Span ratio (L(x)/L)','interpreter','latex') 
h=get(gcf,'Children');
    for i=2:2:size(h,1)
        k=get(h(i,1),'Children');
        for j=1:(length(k)-1)
            if j==1
                set(k(j,1),'LineStyle','-.')
            else
                set(k(j,1),'LineStyle','--')
            end
        end
    end
    
    
%% Horizontal Aymmetric modes
figure
subplot(3,1,1), plot(Coor,phiphi(1,:,HA1),Coor,phiphi(2,:,HA1),Coor,B/2*phiphi(3,:,HA1))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['1st HA'],'interpreter','latex')
    grid on
subplot(3,1,2), plot(Coor,phiphi(1,:,HA2),Coor,phiphi(2,:,HA2),Coor,B/2*phiphi(3,:,HA2))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['2nd HA'],'interpreter','latex')
    grid on
subplot(3,1,3), plot(Coor,phiphi(1,:,HA3),Coor,phiphi(2,:,HA3),Coor,B/2*phiphi(3,:,HA3))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['3rd HA'],'interpreter','latex')
    grid on,xlabel('Span ratio (L(x)/L)','interpreter','latex')
h=get(gcf,'Children');
    for i=2:2:size(h,1)
        k=get(h(i,1),'Children');
        for j=1:(length(k)-1)
            if j==1
                set(k(j,1),'LineStyle','-.')
            else
                set(k(j,1),'LineStyle','--')
            end
        end
    end


%% Vertical Symmetric modes
figure
subplot(3,1,1), plot(Coor,phiphi(1,:,VS1),Coor,phiphi(2,:,VS1),Coor,B/2*phiphi(3,:,VS1))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['1st VS'],'interpreter','latex')
    grid on
subplot(3,1,2), plot(Coor,phiphi(1,:,VS2),Coor,phiphi(2,:,VS2),Coor,B/2*phiphi(3,:,VS2))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['2nd VS'],'interpreter','latex')
    grid on
subplot(3,1,3),plot(Coor,phiphi(1,:,VS3),Coor,phiphi(2,:,VS3),Coor,B/2*phiphi(3,:,VS3))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['3rd VS'],'interpreter','latex')
    grid on,xlabel('Span ratio (L(x)/L)','interpreter','latex')
h=get(gcf,'Children');
    for i=2:2:size(h,1)
        k=get(h(i,1),'Children');
        for j=1:(length(k)-1)
            if j==1
                set(k(j,1),'LineStyle','-.')
            else
                set(k(j,1),'LineStyle','--')
            end
        end
    end

%% Vertical Asymmetric modes
figure
subplot(3,1,1), plot(Coor,phiphi(1,:,VA1),Coor,phiphi(2,:,VA1),Coor,B/2*phiphi(3,:,VA1))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['1st VA'],'interpreter','latex')
    grid on
subplot(3,1,2), plot(Coor,phiphi(1,:,VA2),Coor,phiphi(2,:,VA2),Coor,B/2*phiphi(3,:,VA2))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['2nd VA'],'interpreter','latex')
    grid on
subplot(3,1,3),plot(Coor,phiphi(1,:,VA3),Coor,phiphi(2,:,VA3),Coor,B/2*phiphi(3,:,VA3))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['3rd VA'],'interpreter','latex')
    grid on,xlabel('Span ratio (L(x)/L)','interpreter','latex')

h=get(gcf,'Children');
    for i=2:2:size(h,1)
        k=get(h(i,1),'Children');
        for j=1:(length(k)-1)
            if j==1
                set(k(j,1),'LineStyle','-.')
            else
                set(k(j,1),'LineStyle','--')
            end
        end
    end



%% Torsional Symmetric modes
figure
subplot(3,1,1), plot(Coor,phiphi(1,:,TS1),Coor,phiphi(2,:,TS1),Coor,B/2*phiphi(3,:,TS1))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['1st TS'],'interpreter','latex')
    grid on
subplot(3,1,2), plot(Coor,phiphi(1,:,TS2),Coor,phiphi(2,:,TS2),Coor,B/2*phiphi(3,:,TS2))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['2nd TS'],'interpreter','latex')
    grid on
subplot(3,1,3), plot(Coor,phiphi(1,:,TS3),Coor,phiphi(2,:,TS3),Coor,B/2*phiphi(3,:,TS3))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['3rd TS'],'interpreter','latex')
    grid on,xlabel('Span ratio (L(x)/L)','interpreter','latex')
h=get(gcf,'Children');
    for i=2:2:size(h,1)
        k=get(h(i,1),'Children');
        for j=1:(length(k)-1)
            if j==1
                set(k(j,1),'LineStyle','-.')
            else
                set(k(j,1),'LineStyle','--')
            end
        end
    end

%% Torsional Asymmetric modes
figure
subplot(3,1,1), plot(Coor,phiphi(1,:,TA1),Coor,phiphi(2,:,TA1),Coor,B/2*phiphi(3,:,TA1))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['1st TA'],'interpreter','latex')
    grid on
subplot(3,1,2), plot(Coor,phiphi(1,:,TA2),Coor,phiphi(2,:,TA2),Coor,B/2*phiphi(3,:,TA2))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['2nd TA'],'interpreter','latex')
    grid on
subplot(3,1,3), plot(Coor,phiphi(1,:,TA3),Coor,phiphi(2,:,TA3),Coor,B/2*phiphi(3,:,TA3))
    leg=legend('H','V','T');
    set(leg,'interpreter','latex','Location','EastOutside'), legend('boxoff')
    xlim([xmin xmax]),ylim([-1 1]),title(['3rd TA'],'interpreter','latex')
    grid on,xlabel('Span ratio (L(x)/L)','interpreter','latex')
h=get(gcf,'Children');
    for i=2:2:size(h,1)
        k=get(h(i,1),'Children');
        for j=1:(length(k)-1)
            if j==1
                set(k(j,1),'LineStyle','-.')
            else
                set(k(j,1),'LineStyle','--')
            end
        end
    end




