%% Description
% This script calculates the aeroelastic flutter stability limit based on 
% the general eigenvalue problem where only two modes are assumed to 
% describe an instability. The two modes are simplified to either vertical 
% or torsional motion. The function aerostab_Havard.p provided by Ole iseth
% is used to perform the iteration process. 
% Date 11.04.2012 Hvard Maurset
clc
clear all 
close all 
%% Mode shapes. Eigenvaluesolution for Comparative analysis
Nodes=185;                              % Number of points along the girder
L=3700;                                 % The length of the bridge
xred=linspace(0,1,Nodes);
phiphi=zeros(3,Nodes,2);
phiphi(2,:,1)=sin(pi*xred);
phiphi(3,:,2)=sin(1*pi*xred);
% Plots of the vibration modes
%Mode 1
% figure(1)
% set(gcf, 'Name','VIBRATION MODE 1','Numbertitle','off')
% plot(subplot(3,1,1),xred,phiphi(1,:,1))
% ylabel('\phi_y')
% plot(subplot(3,1,2),xred,phiphi(2,:,1))
% ylabel('\phi_z')
% plot(subplot(3,1,3),xred,phiphi(3,:,1))
% ylabel('\phi_\theta')
% %Mode 2
% figure(2)
% set(gcf,'Name','VIBRATION MODE 2','Numbertitle','off')
% plot(subplot(3,1,1),xred,phiphi(1,:,2))
% ylabel('\phi_y')
% plot(subplot(3,1,2),xred,phiphi(2,:,2))
% ylabel('\phi_z')
% plot(subplot(3,1,3),xred,phiphi(3,:,2))
% ylabel('\phi_\theta')
% The matrix that contains the mode shape integrals (Must be provided as
% input in the aerostab function)
moderInt=zeros(3,3,size(phiphi,3),size(phiphi,3));
for i=1:size(phiphi,3)
    for j=1:size(phiphi,3)
        for n=1:3
            for m=1:3
                integrand(1,:)=phiphi(n,:,i).*phiphi(m,:,j);
                moderInt(n,m,i,j)=trapz(integrand)*L/Nodes;                    
            end
        end       
    end
end
%disp(moderInt)

%% Structural properties

% Modal equivalent distributed masses and MOI
%M0=[25700 25700 2840000];             % 2TFGP
%M0=[22480 22480 2394200];             % BS15GV
%M0=[22580 22580 3433700];             % BS20GV
M0=[23310 23310 6336000];             % BS30/BS30GV


M=zeros(2,2);                                     
M(1,1)=M0*diag(moderInt(:,:,1,1));
M(2,2)=M0*diag(moderInt(:,:,2,2));
                                                
% Natural frequencies and damping ratios
omega=[0.5 ;0.7];
zeta=[0.005 0.005];
% Modal matrices
K=diag(omega).^2*M;                             % Modal stiffness matrix
C=2.*diag(zeta).*M*diag(omega);                 % Modal damping matrix

% Constants
ro=1.25;                                        % Density of air
B=7.5;                                          % Width of one girder                                                
                 
                                             
%% Eigenvalue solution
maxfit=200;                 % Max number of frequency and velocity 
maxVit=1000;                % iterations

V=1;                        % Initial mean wind velocity
dV=1;                       % Velocity increment

A=[];

[Vvec,imS,reS,VCR,OmegaCR]=aerostab_Havard(@aerodynamicderivativesBS30,M,C,K,omega,...
moderInt,ro,B,maxfit,maxVit,V,dV,A);



%% Plotting the results
figure(1)
set(gcf,'Name','Solution of the eigenvalue problem','Numbertitle','off')

plot(subplot(2,1,1),Vvec,imS,'--o')
xlabel('V (m/s)','interpreter','latex')
ylabel('Im($\lambda_n$)','interpreter','latex')
title('Imaginary part of the eigenvalues (damped natural frequencies)',...
    'interpreter','latex')

plot(subplot(2,1,2),Vvec,reS,'--o'),grid on
xlabel('V (m/s)','interpreter','latex')
ylabel('Re($\lambda_n$)','interpreter','latex')
title('Real part of the eigenvalues (damping term,$\mu_n= -v_{n}\omega_n$)',...
    'interpreter','latex')

disp(['The aeroelastic stability limit is ', num2str(VCR), ' m/s'])
disp(['The critical frequency is ' ,num2str(OmegaCR), ' rad/s'])