%% Description 
% This script calculates the flutter stability limit for coupling of one
% horizontal and one torsional mode by using the flutter equations. The
% function flutterstab.m is used to solve the equation system.
% Date: 10.06.2012   Haavard Maurset
clc
clear all
close all
%% Structural properties

% Modal equivalent distributed masses and MOI, choose one.
% M0=[25700 0 0;0 25700 0;0 0 2840000];              % 2TFGP
% M0=[22480 0 0;0 22480 0;0 0 2394200];              % BS15GV
% M0=[22580 0 0;0 22580 0;0 0 3433700];              % BS20GV
% M0=[23310 0 0;0 23310 0;0 0 6336000];              % BS30/BS30GV            
                                                    
m_z=M0(2,2);                                    
m_theta=M0(3,3);                                      

% Natural frequencies and damping ratiosf 
omega_z=0.5;
omega_theta=2;
gamma=[1.4 1.5 1.6 1.8 2.0 2.2 2.4 3.0];                                 
omega_theta2=gamma.*omega_z;                    % Frequency ratio vector
zeta=[0.005 0.005];                             % zeta=[zeta_z zeta_theta]

% Constants
ro=1.25;                                        % Density of air
B='value here';                                 % Width of one girder

beta_z=ro*B^2/m_z;                              % Coefficients used for 
beta_theta=ro*B^4/m_theta;                      % simplifications in the 
                                                % Flutter equations

% Specifying the shapewise similarity of the two modes                                                
psi='value her';
%% Flutter solution

Vred='value her';                    % Creating reduced velocity vector
RAD=1;

[ImaginaryRoot,RealRoot,ReRoot,OmgRedIm,OmgRedRe,Vcr,OmegaCr,VredCr,OmgRedCr,Vred_omega]=flutterstab(@aerodynamicderivativesBS15GV,omega_theta,omega_theta2,beta_z,beta_theta,zeta,psi,gamma,Vred,RAD,B);    


%% Plotting the results
n=1;           % Defining for which frequency ratio results will be plotted
hold on
figure(1)
plot(Vred,OmgRedRe(n,:),'r',Vred,OmgRedIm(n,:),'--b')
set(legend('Real Root','Imaginary Root'),'interpreter','latex'), legend('boxoff')
%ylim([0.8*min(OmgRedIm(n,:)) 1.2*max(OmgRedIm(n,:))])
xlabel('Reduced velocity $\hat{V}=V/(B^*\omega_{CR})$','interpreter','latex')
ylabel('Reduced frequency $\hat{\omega}_{CR}=\omega_{CR}/\omega_{\theta}$','interpreter','latex')
%title('Development of the real and imaginary roots ','interpreter','latex')
line([1 1]*VredCr(n),[0.8*min(OmgRedRe(n,:)) OmgRedCr(n)],'Color',[0 0.5 0])
line([min(Vred) VredCr(n)],[1 1]*OmgRedCr(n),'Color',[0 0.5 0])

figure(2)
plot(gamma,Vred_omega,'-ob')
xlabel('Frequency ratio $\omega_{\theta}/\omega_z$','interpreter','latex')
ylabel('Reduced critical velocity $V_{Cr}/(B^*\omega_{\theta})$','interpreter','latex')

disp(['The flutter stability limit is ', num2str(Vcr(n)), ' m/s'])
disp(['The critical frequency is ' ,num2str(OmegaCr(n)), ' rad/s'])





