%% Description
% This script calculates the aeroelastic stability in terms of the critical
% velocity and the critical frequency. The input to the function is given
% in the m-file eigenvalue.m
% Date: 10.06.2012   Haavard Maurset
%% Creating the function

function [Omega,v_n,omega_n,omega,Vvec,ImLambda,ReLambda,Vcr,OmegaCr]=aeroelasticstab(aerodynamicderivatives,M,C,K,omg0,moderInt,ro,B,maxVit,maxfit,V0,dV,phiphi)
%% Calculating properties
% I and zerosM are the matrices in matrix A given in Equation 4.42 in
% Section 4.4. IM is the identity matrix 

I=diag(ones(1,size(phiphi,3)));              
zerosM=zeros(size(phiphi,3),size(phiphi,3)); 
IM=diag(ones(1,2*size(phiphi,3)));            
%% Eigenvalue solution with an iterative process
V(1)=V0;
                                    % Initial assumptions of frequency
vn_min=0.5;                         % and damping including aerodynamic
omega(1)=omg0;                      % damping as well as structural damping

i=2;                                % Next step, starting with i=2
                         
while vn_min > 0 && i <= maxVit
V(i)=V(i-1)+dV;                     % Increasing the velocity by increment
                                    % dV
Vvec(i-1)=V(i);                     % Creating velocity vector starting
                                    % at velocity V0+dV

Vred=V(i)/(omega(i-1)*B);

% Importing the aerodynamic derivatives
% AD=[P1* P2* P3* P4* P5* P6* H1* H2* H3* H4* H5* H6* A1* A2* A3* A4* A5* A6*]^T
AD=aerodynamicderivatives(Vred,omega(i-1));

% Aerodynamic damping matrix
Cae_h=ro*B^2/2*omega(i-1)*[AD(1) AD(5) B*AD(2);...    
                       AD(11) AD(7) B*AD(8);...       
                       B*AD(17) B*AD(13) B^2*AD(14)];

% Aerodynamic stiffness matrix                   
Kae_h=ro*B^2/2*omega(i-1)^2*[AD(4) AD(6) B*AD(3);...
                       AD(12) AD(10) B*AD(9);...      
                       B*AD(18) B*AD(16) B^2*AD(15)];

    Cae=zeros(size(phiphi,3),size(phiphi,3));  
    Kae=zeros(size(phiphi,3),size(phiphi,3));
    for k=1:size(phiphi,3)
        for l=1:size(phiphi,3)
            for n=1:3
                for m=1:3
Cae(k,l)=Cae(k,l)+moderInt(n,m,k,l).*Cae_h(n,m);    % Modal aerodynamic
Kae(k,l)=Kae(k,l)+moderInt(n,m,k,l).*Kae_h(n,m);    % stiffness and damping
                                                    % matrices
                                                    % N_mod x N_mod
                end
            end
        end
    end


A=[-M\(C-Cae) -M\(K-Kae);I zerosM];
lambda(:,i-1)=eig(A,IM);
ReLambda(:,i-1)=real(lambda(:,i-1));
ImLambda(:,i-1)=imag(lambda(:,i-1));
omega_n(:,i-1)=abs(lambda(:,i-1));
v_n(:,i-1)=-real(lambda(:,i-1))./omega_n(:,i-1);
[vn_min,Pos]=min(v_n(:,i-1));           % Finding the mode with the lowest 
Omega(1,i-1) = omega_n(Pos,i-1);        % damping value

j=1;                                    % Resetting iterativ counter after 
                                        % incrementing the velocity
    % Frequency iterations
    while abs(Omega(j,i-1)-omega(i-1)) > 0.0000001  && j <= maxfit
        omega(i-1)=Omega(j,i-1);
        j=j+1;                          % Update iteration counter
        
        % Updating the aerodynamic derivatives for the new iterativ
        % frequency, and also the aerodynamic matrices
        AD=aerodynamicderivatives(Vred,omega(i-1));

        Cae_h=ro*B^2/2*omega(i-1)*[AD(1) AD(5) B*AD(2);...        
                                AD(11) AD(7) B*AD(8);...         
                                B*AD(17) B*AD(13) B^2*AD(14)];
                   
        Kae_h=ro*B^2/2*omega(i-1)^2*[AD(4) AD(6) B*AD(3);...      
                                AD(12) AD(10) B*AD(9);...        
                                B*AD(18) B*AD(16) B^2*AD(15)];

        Cae=zeros(size(phiphi,3),size(phiphi,3));  
        Kae=zeros(size(phiphi,3),size(phiphi,3));
            for k=1:size(phiphi,3)
                for l=1:size(phiphi,3)
                    for n=1:3
                        for m=1:3
                        Cae(k,l)=Cae(k,l)+moderInt(n,m,k,l).*Cae_h(n,m);    
                        Kae(k,l)=Kae(k,l)+moderInt(n,m,k,l).*Kae_h(n,m);    
                                                   
                        end
                    end
                end
            end
            
        A=[-M\(C-Cae) -M\(K-Kae);I zerosM];
        lambda(:,i-1)=eig(A,IM);
        ReLambda(:,i-1)=real(lambda(:,i-1));
        ImLambda(:,i-1)=imag(lambda(:,i-1));
        omega_n(:,i-1)=abs(lambda(:,i-1));
        v_n(:,i-1)=-real(lambda(:,i-1))./omega_n(:,i-1);
        [vn_min,Pos]=min(v_n(:,i-1));
        Omega(j,i-1) = omega_n(Pos,i-1);  
    
    end
 % When the velocity becomes close to the critical the increment is reduced
 % to improve accuracy. Must be adjusted.
    if min(abs(ReLambda(:,i-1))) < 0.005 % && V(i) > 100
        dV=0.5*dV;       
        if dV <=0.01
            dV=0.01;
        end
    end

    omega(i)=Omega(j,i-1);  % Updating the frequency vector in element i 
    i=i+1;                  % Updating the velocity increment counter

    

end

Vcr=Vvec(length(Vvec));             % Defining the critical velocity and 
OmegaCr=omega(length(omega));       % frequency as the values in the last 
                                    % element of the vectors
