%% Description
% This script calculates the flutter stability in terms of the critical
% velocity and the critical frequency. The input to the function is given 
% in the m-file fluttersolution.m
% Date: 10.06.2012   Haavard Maurset
%% Creating the function
function [ImaginaryRoot,RealRoot,ReRoot,OmgRedIm,OmgRedRe,Vcr,OmegaCr,VredCr,OmgRedCr,Vred_omega]=flutterstab(aerodynamicderivatives,omega_theta,omega_theta2,beta_z,beta_theta,zeta,psi,gamma,Vred,RAD,B)
%% Flutter solution
for j=1:length(gamma)
    for i = 1:length(Vred)
    
    AD=aerodynamicderivatives(Vred(1,i),RAD);

% CALCULATING THE REAL ROOTS OF THE FLUTTER EQUATIONS
R4=gamma(j)^2*(1 + 0.5*beta_z*AD(10) + 0.5*beta_theta*AD(15) + 0.25*beta_z*beta_theta*(AD(13)*AD(8)*psi - AD(14)*AD(7) + AD(15)*AD(10) - AD(16)*AD(9)*psi));
R3=gamma(j)*(zeta(2)*beta_z*gamma(j)*AD(7) + zeta(1)*beta_theta*AD(14));
R2=-(1 + gamma(j)^2 +4*gamma(j)*zeta(1)*zeta(2) + 0.5*beta_z*gamma(j)^2*AD(10) + 0.5*beta_theta*AD(15));
R1=0;
R0=1;

    Realpar=[R4 R3 R2 R1 R0];
    RealRoot(:,i,j)=real(roots(Realpar));
    RRoot=RealRoot(:,i,j);
    m=1;
        for k=1:4
            if RRoot(k,1)>=0
            ReRoot(m,1)=RRoot(k,1);
            m=m+1;
            end
        end
    OmgRedRe(j,i)=max(ReRoot(:,1)); %Must be changed dependent on the roots
    ReRoot=[];
    RRoot=[];

% CALCULATING THE IMAGINARY ROOTS OF THE FLUTTER EQUATIONS

I3=gamma(j)^2*((1/8)*beta_z*beta_theta*( AD(7)*AD(15) - AD(8)*AD(16)*psi - AD(9)*AD(13)*psi + AD(10)*AD(14)) + 0.25*(beta_z*AD(7) + beta_theta*AD(14)));
I2=-(zeta(1)*(0.5*beta_theta*AD(15) + gamma(j)) + zeta(2)*gamma(j)^2*(0.5*beta_z*AD(10) + 1) );
I1=-0.25*(beta_z*gamma(j)^2*AD(7) + beta_theta*AD(14));
I0=zeta(1)*gamma(j) + zeta(2);

    ImaginaryPar=[I3 I2 I1 I0];
    ImaginaryRoot(:,i,j)=real(roots(ImaginaryPar));
    IRoot=ImaginaryRoot(:,i,j);
    n=1;
        for k=1:3
            if IRoot(k,1)>=0
            ImRoot(n,1)=IRoot(k,1);
            n=n+1;
            end
        end
    OmgRedIm(j,i)=max(ImRoot(:,1)); %Must be changed dependent on the roots
    ImRoot=[];
    IRoot=[];

    end
end

%% Finding the critical values

% Calculating the difference in frequency for the real and imaginary
% solutions for the same reduced velocity
for m = 1:length(gamma)                
    for k = 1:length(Vred)
    diffOmgRed(m,k)=abs(OmgRedRe(m,k)-OmgRedIm(m,k)); 
    end
    
    % Finding the positions where the difference is the smallest
    [min_diffOmgRed,Pos]=min(diffOmgRed(m,:));   

    VredCr(m)=Vred(Pos);
    OmgRedCr(m)=OmgRedRe(m,Pos);
    OmegaCr(m)=OmgRedCr(m)*omega_theta2(m);
    Vcr(m)=omega_theta2(m)*B*VredCr(m)*OmgRedCr(m);
    Vred_omega(m)=VredCr(m)*OmgRedCr(m);
    
end




